import { App } from '@kevisual/router';
import * as redisLib from './modules/redis.ts';
import * as minioLib from './modules/minio.ts';
import * as sequelizeLib from './modules/sequelize.ts';
import { useContextKey, useContext } from '@kevisual/use-config/context';
import { SimpleRouter } from '@kevisual/router/simple';
import { OssBase } from '@kevisual/oss/services';
export const router = useContextKey('router', () => new SimpleRouter());
export const runtime = useContextKey('runtime', () => {
  return {
    env: process.env.NODE_ENV || 'development',
    type: 'server',
  };
});
export const oss = useContextKey(
  'oss',
  () =>
    new OssBase({
      client: minioLib.minioClient,
      bucketName: minioLib.bucketName,
      prefix: '',
    }),
);
export const redis = useContextKey('redis', () => redisLib.redis);
export const redisPublisher = useContextKey('redisPublisher', () => redisLib.redisPublisher);
export const redisSubscriber = useContextKey('redisSubscriber', () => redisLib.redisSubscriber);
export const minioClient = useContextKey('minioClient', () => minioLib.minioClient);
export const sequelize = useContextKey('sequelize', () => sequelizeLib.sequelize);

const init = () => {
  return new App<{ sequelize: typeof sequelize }>({
    serverOptions: {
      cors: {
        origin: '*',
      },
      // httpType: 'https',
    },
    io: true,
    routerContext: {
      sequelize,
    },
  });
};
export const app = useContextKey('app', init);
